@@ -1,7 +1,7 @@
 """
 Type annotations for kinesisanalyticsv2 service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalyticsv2/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
@@ -45,6 +45,7 @@ ApplicationStatus = Literal[
     "FORCE_STOPPING",
     "MAINTENANCE",
     "READY",
+    "ROLLED_BACK",
     "ROLLING_BACK",
     "RUNNING",
     "STARTING",
